@@ -84,6 +84,8 @@ if ( $] < 5.010000 ) {
 			
 			# Crazy optimized loop to find and handle LINQ::END
 			# within @got
+			# uncoverable condition count:1
+			# uncoverable condition count:5
 			push( @$cache, shift @got )
 				and ref( $got = $cache->[-1] )
 				and $got == LINQ::END()
@@ -103,7 +105,7 @@ if ( $] < 5.010000 ) {
 package LINQ::Iterator;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.000_008';
+our $VERSION   = '0.000_009';
 
 use Role::Tiny::With     ();
 use LINQ::Util::Internal ();
@@ -136,7 +138,8 @@ sub to_list {
 	# so remove all the magic and act like a
 	# plain old arrayref.
 	#
-	if ( tied( $self ) ) {
+	if ( tied( @$self ) ) {
+		no warnings;
 		untie( @$self );
 		@$self = @list;
 	}
@@ -144,6 +147,19 @@ sub to_list {
 	@list;
 } #/ sub to_list
 
+
+sub to_array {
+	my $self = shift;
+	
+	if ( my $guts = $self->_guts ) {
+		tie ( my @tied, 'LINQ::Iterator::_LazyList', undef );
+		@{ tied( @tied ) } = @$guts;
+		return \@tied;
+	}
+	
+	$self->LINQ::Collection::to_array( @_ );
+}
+
 sub element_at {
 	my $self = shift;
 	
@@ -209,6 +225,8 @@ LINQ::Iterator supports all the methods defined in L<LINQ::Collection>.
 
 =item to_list
 
+=item to_array
+
 =item to_iterator
 
 =end trustme
